@@ -52,11 +52,21 @@ class Connection():
 
     def __format_clause__(self, *clause):
         arr = []
+
+        def FormatCondition(_field_condition):
+            if not "(" in _field_condition and ")" in _field_condition:
+                _field_condition = f'{self._table}.{_field_condition.strip()}'
+            return  _field_condition
+
+        def FormatField(_condition):
+            return _condition.strip() if '.' in _condition else FormatCondition(_condition)
+
         for c in clause:
             if not ',' in c:
-                arr.append(c.strip() if '.' in c else f'{self._table}.{c.strip()}')
+                arr.append(FormatField(c))
             else:
-                arr = arr + [s.strip() if '.' in s else f'{self._table}.{s.strip()}' for s in c.split(',')]
+                arr = arr + [FormatField(s) for s in c.split(',')]
+
         return arr
 
     def __format_fields__(self, *fields):
