@@ -26,7 +26,7 @@ class Entity():
                             self.add(k, kw[k])
                         else:
                             self[k].value = kw[k]
-                            self.__metadata__['data'][k] = self[k].value 
+                            self.__metadata__['data'][k] = self[k].value
                     elif self[k].__class__.__name__.startswith("Obj"):
                         group_data = {key.replace(f"{k}.",''):value for key, value in kw.items() if key.startswith(f"{k}.")}
                         if len(group_data) > 0:
@@ -61,8 +61,10 @@ class Entity():
         try:
             if not item.startswith("__") and not "entity.datatype" in str(value.__class__):
                 if self[item]:
+                    if hasattr(value, '__context__') and not value.__context__:
+                        value.__context__ = self
                     self[item].value = value
-                    self.__metadata__['data'][item] = self[item].value
+                    self.__metadata__['data'][item] = self[item].value.toJSON() if hasattr(self[item].value, 'toJSON') else self[item].value
                     if self.__context__:
                         _context = self.__context__['entity']
                         _context_key = self.__context__['key']
