@@ -18,10 +18,12 @@ def main(arg):
 
     conn = bravaorm.Connection(db_user="root", db_password="1234", db_host="127.0.0.1", db_port=3306, db_database="gofans", db_charset="utf8mb4", log_level='debug')
 
-    usuariosDirect = conn.directs_usuarios.inner("websockets").where("id_usuario!=47, id_direct=1").all
+    resultado = conn.execute("SELECT * FROM usuarios", "Usuario")
 
-    print(usuariosDirect.toJSON())
+    for usr in resultado:
+        print(usr.toJSON())
 
+    print("\n\nFim conversa")
     conn.close()
 
 if __name__ == "__main__":
